@@ -7,19 +7,25 @@ By Greg Ward <gward@python.net>
 See http://optik.sourceforge.net/
 """
 
-# Copyright (c) 2001 Gregory P. Ward.  All rights reserved.
+# Copyright (c) 2001-2006 Gregory P. Ward.  All rights reserved.
 # See the README.txt distributed with Optik for licensing terms.
 
-__revision__ = "$Id: __init__.py,v 1.11 2002/04/11 19:17:34 gward Exp $"
+__revision__ = "$Id: __init__.py 526 2006-07-23 15:19:14Z greg $"
 
-__version__ = "1.3"
+__version__ = "1.5.3"
 
 
 # Re-import these for convenience
 from optik.option import Option
-from optik.option_parser import \
-     OptionParser, SUPPRESS_HELP, SUPPRESS_USAGE, STD_HELP_OPTION
-from optik.errors import OptionValueError
+from optik.option_parser import *
+from optik.help import *
+from optik.errors import *
+
+from optik import option, option_parser, help, errors
+__all__ = (option.__all__ +
+           option_parser.__all__ +
+           help.__all__ +
+           errors.__all__)
 
 
 # Some day, there might be many Option classes.  As of Optik 1.3, the
